#ifndef ABOUTDLG_H
#define ABOUTDLG_H

#include "licensedlg.h"
#include "creditsdlg.h"
#include <QtGui/QDialog>
#include <QDesktopServices>
#include <QUrl>

namespace Ui {
    class AboutDlg;
}

class AboutDlg : public QDialog {
    Q_OBJECT
    Q_DISABLE_COPY(AboutDlg)
public:
    //! Constructor
    explicit AboutDlg(QWidget *parent = 0);
    //! Destructor
    virtual ~AboutDlg();

private:
    Ui::AboutDlg *m_ui;
    CreditsDlg *credits;
    LicenseDlg *license;

private slots:
    //! Opens credits dialog.
    void on_webButton_clicked();
    void on_creditsButton_clicked();
    //! Shows default GNU license.
    void on_licenseButton_clicked();
};

#endif // ABOUTDLG_H
